/* This is "trap1.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary. */

/* This program is an implementation and a test driver for the
   trapezoidal method of numerical integration. */


#include <stdio.h>
#include <math.h>



/* Returns sin(x)+2. */

double integrand (double x)
{
  return(sin(x) + 2);
}



/* Approximates the definite integral of "integrand" between
   a low bound of "a" and a high bound of "b" using the
   trapezoidal method with "n" trapezoids. */

double trapezoidal (double a, double b, int n)
{

  double width,    /* The width of each trapezoid */
         sum;      /* Running sum of trapezoidal side heights */

  int i;           /* Counts though the trapezoids */

  width = (b - a) / n;
  sum = (integrand(a) + integrand(b)) / 2;

  for (i = 1; i <= n-1; i = i+1) {
    sum = sum + integrand(a+i*width);
  }

  return(width * sum);

}



/* Test driver for "trapezoidal". */

void main (void)
{

  int ntraps;
  double low, high;

  printf("Enter number of trapezoids to use: ");
  scanf("%d", &ntraps);

  printf("Enter low bound of integration: ");
  scanf("%lf", &low);

  printf("Enter high bound of integration: ");
  scanf("%lf", &high);

  printf("%g\n", trapezoidal(low, high, ntraps));

}
