(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9314,        327]*)
(*NotebookOutlinePosition[     10004,        352]*)
(*  CellTagsIndexPosition[      9960,        348]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["This notebook contains the ", "Text"],
  StyleBox["Mathematica", "Text",
    FontSlant->"Italic"],
  StyleBox[" commands from Chapter 2 of ", "Text"],
  StyleBox["Introduction to Scientific Programming", "Text",
    FontSlant->"Italic"],
  StyleBox[" by Joseph L. Zachary.", "Text"]
}], "Subsection"],

Cell["\<\
(2.1)  The simplest kind of an expession is a number.  It evaluates \
to itself.\
\>", "Text"],

Cell["57.8", "Input"],

Cell[TextData[{
  "(2.2)  This ill-formed number is an example of a syntax error.  Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot make sense of it, it reports an errror."
}], "Text"],

Cell["57,8", "Input"],

Cell["\<\
(2.3)  Here we compute the quotient of two rational numbers.  \
Notice that the answer is expressed as an exact fraction in lowest \
terms.\
\>", "Text"],

Cell["57800000 / 5713000000", "Input"],

Cell["\<\
(2.4)  We demonstrate that the quotient from (2.3) is exact by \
multiplying it by the divisor, which yields the dividend.\
\>", "Text"],

Cell["289/28565 * 5713000000", "Input"],

Cell["\<\
(2.5)  We do the same computation as in (2.3), but this time using \
floating-point numbers.  We know these are floating-point numbers because \
they contain decimal points.  The answer is rounded off to ten digits, not \
counting the leading zero.\
\>", "Text"],

Cell["57800000. / 5713000000.", "Input"],

Cell["\<\
(2.6)  We do the computation from (2.5) one more time, this time \
using scientific notation to write the floating-point numbers.\
\>", "Text"],

Cell["57.8*^6 / 5.713*^9", "Input"],

Cell["\<\
(2.7)  We illustrate that floating-point arithmetic is not exact by \
multiplying the quotient from the previous example by the divisor.  The \
number that we get back is almost, but not exactly, the same as the dividend.\
\
\>", "Text"],

Cell[".0101173 * 5.713*^9", "Input"],

Cell[TextData[{
  "(2.8)  This illustrates how, by canelling units, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does dimensional analysis."
}], "Text"],

Cell["72 in * 2.54 cm/in", "Input"],

Cell["\<\
(2.9)  Here we square a rational number by using the exponentiation \
operator.\
\>", "Text"],

Cell["5280^2", "Input"],

Cell["\<\
(2.10)  This example shows how floating-point and rational numbers \
can be mixed in a single expression.  Because a floating-point number is \
involved, the answer is expressed as a floating-point number.\
\>", "Text"],

Cell[".0101173 * 27878400", "Input"],

Cell["\<\
(2.11)  We repeat the calculation from (2.10), this time using only \
rational numbers.  Notice that the result is expressed as a rational \
number.\
\>", "Text"],

Cell["289/28565 * 27878400", "Input"],

Cell["\<\
(2.12)  Here we divide two floating-point numbers, obtaining an \
intermediate floating-point result, which we multiply by a rational number.  \
Because the final multiplication involves both a floating-point number and a \
rational number, the rational number is first converted into floating-point \
form.\
\>", "Text"],

Cell["(57.8*^6 / 5.713*^9) * 27878400", "Input"],

Cell["\<\
(2.13)  This is the same calculation as in (2.12), but here we \
explicitly compute the square of 5280.\
\>", "Text"],

Cell["(57.8*^6 / 5.713*^9) * (5280^2)", "Input"],

Cell["\<\
(2.14)  This is an example of the user of the \"Sqrt\" built-in \
function.  It returns the square root of its parameter.\
\>", "Text"],

Cell["Sqrt[282053.]", "Input"],

Cell["\<\
(2.15)  The parameter to \"Sqrt\" can be an arbitrary expression.  \
Here we take the square root of the value of an expression that involves \
division, exponentiation, and multiplication.\
\>", "Text"],

Cell["Sqrt[(57.8*^6 / 5.713*^9) * (5280^2)]", "Input"],

Cell["\<\
(2.16)  Here we take the same square root as in (2.15), but we use \
rational numbers.  An exact result is produced using a radical.\
\>", "Text"],

Cell["Sqrt[(57800000 / 5713000000) * (5280^2)]", "Input"],

Cell["\<\
(2.17)  The \"N\" built-in function converts a rational number into \
floating-point form.\
\>", "Text"],

Cell["N[17952 * Sqrt[5/5713]]", "Input"],

Cell["\<\
(2.18)  The notebook interface permits the entry of expressions in \
a typeset format.  Here is a different version of (2.14).\
\>", "Text"],

Cell[BoxData[
    \(\@282053.\)], "Input"],

Cell["(2.19)  And here is a different version of (2.16).", "Text"],

Cell[BoxData[
    \(\@\(\(57800000\/5713000000\) 5280\^2\)\)], "Input"],

Cell["\<\
(2.21)  There is a limit on the sizes of rational numbers that can \
be computed.  Although the limit aries from computer to computer, this \
expression will probably exceed the limit on your computer.  You will almost \
certainly end up having to abort the computation.\
\>", "Text"],

Cell["10^600000", "Input"],

Cell[TextData[{
  "(2.22)  Even though this expression involves large exponents, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is able to quickly reduce this to 1."
}], "Text"],

Cell["10^(600000-600000)", "Input"],

Cell["\<\
(2.23)  This is algebraically identical to (2.22), but you will \
nevertheless have to abort this calculation.\
\>", "Text"],

Cell["10^600000 / 10^600000", "Input"],

Cell[TextData[{
  "(2.24)  The value of this constant is the precision of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s floating-point numbers on your computer."
}], "Text"],

Cell["$MachinePrecision", "Input"],

Cell["(2.25)  This is an exact rational calculation ...", "Text"],

Cell["1234567890^2", "Input"],

Cell[TextData[{
  "(2.26)  ... and this is the same calculation done with floating-point \
numbers.  Notice that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " only displays the first six digits of the mantissa."
}], "Text"],

Cell["1234567890.^2.", "Input"],

Cell["\<\
(2.27)  By using the built-in function \"InputForm\", we can see \
all of the digits of the number calculated in (2.26).  Notice that only 16 \
digits are available, even though there were 17 digits in the rational answer \
calculated in (2.25).\
\>", "Text"],

Cell["InputForm[1234567890.^2.]", "Input"],

Cell["\<\
(2.28)  Here we look at all of the digits in a quotient we \
evaluated several times earlier.\
\>", "Text"],

Cell["InputForm[57.8*^6 / 5.713*^9]", "Input"],

Cell["\<\
(2.29)  We use the 16-digit result from (2.28) to recalculate \
(2.10), where we earlier used only a six-digit multiplicand.  The product \
differs in the sixth digit.\
\>", "Text"],

Cell["0.01011727638718711 * 27878400", "Input"],

Cell["\<\
(2.30)  This is the largest floating-point number on your computer.\
\
\>", "Text"],

Cell["$MaxMachineNumber", "Input"],

Cell["\<\
(2.31)  And this is the smallest floating-point number on your \
computer.\
\>", "Text"],

Cell["$MinMachineNumber", "Input"],

Cell["\<\
(2.32)  If you try to calculate a floating-point number that is too \
big, you'll get an overflow error.\
\>", "Text"],

Cell["10.^1000000000.", "Input"],

Cell["\<\
(2.33)  And if you try to calculate a floating-point number that is \
too small, you'll get an underflow error.\
\>", "Text"],

Cell["10.^-1000000000.", "Input"],

Cell["\<\
(2.34)  These are all of the digits in the floating-point \
calculation for the problem studied in Chapter 2.\
\>", "Text"],

Cell["InputForm[Sqrt[(57.8*^6 / 5.713*^9) * (5280.^2)]]", "Input"],

Cell["\<\
(2.35)  And these are all the digits in the rational calculation, \
after it has been converted to floating-point form at the last step.\
\>", 
  "Text"],

Cell["\<\
InputForm[N[17952 * Sqrt[5/5713]]]
\
\>", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{194, Automatic}, {Automatic, 102}},
Magnification->1,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 328, 8, 66, "Subsection"],
Cell[2062, 61, 104, 3, 32, "Text"],
Cell[2169, 66, 21, 0, 27, "Input"],
Cell[2193, 68, 207, 5, 50, "Text"],
Cell[2403, 75, 21, 0, 27, "Input"],
Cell[2427, 77, 163, 4, 50, "Text"],
Cell[2593, 83, 38, 0, 27, "Input"],
Cell[2634, 85, 146, 3, 50, "Text"],
Cell[2783, 90, 39, 0, 27, "Input"],
Cell[2825, 92, 272, 5, 68, "Text"],
Cell[3100, 99, 40, 0, 27, "Input"],
Cell[3143, 101, 153, 3, 50, "Text"],
Cell[3299, 106, 35, 0, 27, "Input"],
Cell[3337, 108, 247, 5, 68, "Text"],
Cell[3587, 115, 36, 0, 27, "Input"],
Cell[3626, 117, 166, 5, 32, "Text"],
Cell[3795, 124, 35, 0, 27, "Input"],
Cell[3833, 126, 103, 3, 32, "Text"],
Cell[3939, 131, 23, 0, 27, "Input"],
Cell[3965, 133, 229, 4, 68, "Text"],
Cell[4197, 139, 36, 0, 27, "Input"],
Cell[4236, 141, 172, 4, 50, "Text"],
Cell[4411, 147, 37, 0, 27, "Input"],
Cell[4451, 149, 331, 6, 86, "Text"],
Cell[4785, 157, 48, 0, 27, "Input"],
Cell[4836, 159, 127, 3, 50, "Text"],
Cell[4966, 164, 48, 0, 27, "Input"],
Cell[5017, 166, 145, 3, 50, "Text"],
Cell[5165, 171, 30, 0, 27, "Input"],
Cell[5198, 173, 213, 4, 50, "Text"],
Cell[5414, 179, 54, 0, 27, "Input"],
Cell[5471, 181, 156, 3, 50, "Text"],
Cell[5630, 186, 57, 0, 27, "Input"],
Cell[5690, 188, 114, 3, 32, "Text"],
Cell[5807, 193, 40, 0, 27, "Input"],
Cell[5850, 195, 150, 3, 50, "Text"],
Cell[6003, 200, 42, 1, 31, "Input"],
Cell[6048, 203, 66, 0, 32, "Text"],
Cell[6117, 205, 71, 1, 49, "Input"],
Cell[6191, 208, 294, 5, 68, "Text"],
Cell[6488, 215, 26, 0, 27, "Input"],
Cell[6517, 217, 189, 5, 50, "Text"],
Cell[6709, 224, 35, 0, 27, "Input"],
Cell[6747, 226, 134, 3, 50, "Text"],
Cell[6884, 231, 38, 0, 27, "Input"],
Cell[6925, 233, 188, 5, 50, "Text"],
Cell[7116, 240, 34, 0, 27, "Input"],
Cell[7153, 242, 65, 0, 32, "Text"],
Cell[7221, 244, 29, 0, 27, "Input"],
Cell[7253, 246, 236, 6, 50, "Text"],
Cell[7492, 254, 31, 0, 27, "Input"],
Cell[7526, 256, 269, 5, 68, "Text"],
Cell[7798, 263, 42, 0, 27, "Input"],
Cell[7843, 265, 117, 3, 32, "Text"],
Cell[7963, 270, 46, 0, 27, "Input"],
Cell[8012, 272, 191, 4, 50, "Text"],
Cell[8206, 278, 47, 0, 27, "Input"],
Cell[8256, 280, 93, 3, 32, "Text"],
Cell[8352, 285, 34, 0, 27, "Input"],
Cell[8389, 287, 98, 3, 32, "Text"],
Cell[8490, 292, 34, 0, 27, "Input"],
Cell[8527, 294, 128, 3, 32, "Text"],
Cell[8658, 299, 32, 0, 27, "Input"],
Cell[8693, 301, 135, 3, 50, "Text"],
Cell[8831, 306, 33, 0, 27, "Input"],
Cell[8867, 308, 133, 3, 50, "Text"],
Cell[9003, 313, 66, 0, 27, "Input"],
Cell[9072, 315, 163, 4, 50, "Text"],
Cell[9238, 321, 60, 3, 42, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

