(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4755,        156]*)
(*NotebookOutlinePosition[      5392,        179]*)
(*  CellTagsIndexPosition[      5348,        175]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["This notebook contains the ", "Text"],
  StyleBox["Mathematica", "Text",
    FontSlant->"Italic"],
  StyleBox[" commands from Chapter 3 of ", "Text"],
  StyleBox["Introduction to Scientific Programming", "Text",
    FontSlant->"Italic"],
  StyleBox[" by Joseph L. Zachary.", "Text"]
}], "Subsection"],

Cell["\<\
(3.4)  This calculates the circumference of the earth in \
kilometers, beginning from Eratosthenes's measurements.\
\>", "Text"],

Cell["360 / 7.2 * 5000. * 0.1575", "Input"],

Cell["\<\
(3.5)  We can save the value of the expression from (3.4) into the \
variable \"circumference\" by using an assignment expression.\
\>", "Text"],

Cell["circumference = 360 / 7.2 * 5000. * 0.1575", "Input"],

Cell["\<\
(3.6)  Now that we have given \"circumference\" a floating-point \
value, we can use it as if it were a floating-point number.  We can, for \
example, determine its value.\
\>", "Text"],

Cell["circumference", "Input"],

Cell["\<\
(3.7)  We can also use its value in more complicated expressions.\
\
\>", "Text"],

Cell["diameter = circumference / 3.14159", "Input"],

Cell["\<\
(3.8)  Here we recompute \"circumference\" using parentheses to \
explicitly group the operands and operators from (3.5).\
\>", "Text"],

Cell["circumference = (360 / 7.2) * (5000. * 0.1575)", "Input"],

Cell["\<\
(3.9)  We compute the diameter of the earth using two-digit \
approximations for its circumference and for pi.  Compare the result with \
(3.7).\
\>", "Text"],

Cell["3.9*^4 / 3.1", "Input"],

Cell["\<\
(3.10)  This is part of an interval arithmetic computation.  We use \
the smallest possible value (7.15) for the angle measured by Eratosthenes, \
the largest possible value (5050) for the distance from Alexandria to Cyrene, \
and the largest possible value for the conversion factor from stadia to \
kilometers.  This gives us the largest possible value for the circumference \
of the earth.\
\>", "Text"],

Cell["(360 / 7.15) * (5050. * 0.15755)", "Input"],

Cell["\<\
(3.11)  We compute the smallest possible value for the \
circumference of the earth by peturbing the measurements in the other \
direction.\
\>", "Text"],

Cell["(360 / 7.25) * (4950. * 0.15745)", "Input"],

Cell["\<\
(3.12)  We do an interval arithmetic calculation \"by hand\" to \
obtain an upper bound ...\
\>", "Text"],

Cell["200.5 - 185.5", "Input"],

Cell["(3.13) ... and a lower bound.", "Text"],

Cell["199.5 - 186.5", "Input"],

Cell[TextData[{
  "(3.14)  Alternatively, we can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in \"Interval\" function, which will do the interval arithmetic \
calculation for us."
}], "Text"],

Cell["Interval[{199.5, 200.5}] - Interval[{185.5, 186.5}]", "Input"],

Cell["\<\
(3.15)  We use \"Interval\" to do the interval arithmetic \
calculation that we did \"by hand\" in (3.10) and (3.11).\
\>", "Text"],

Cell["\<\
(360 / Interval[{7.15,7.25}]) *
        (Interval[{4950,5050}] * Interval[{0.15745,0.15755}])\
\>", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{128, Automatic}, {Automatic, 32}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 328, 8, 66, "Subsection"],
Cell[2062, 61, 138, 3, 50, "Text"],
Cell[2203, 66, 43, 0, 27, "Input"],
Cell[2249, 68, 154, 3, 50, "Text"],
Cell[2406, 73, 59, 0, 27, "Input"],
Cell[2468, 75, 195, 4, 50, "Text"],
Cell[2666, 81, 30, 0, 27, "Input"],
Cell[2699, 83, 91, 3, 32, "Text"],
Cell[2793, 88, 51, 0, 27, "Input"],
Cell[2847, 90, 145, 3, 50, "Text"],
Cell[2995, 95, 63, 0, 27, "Input"],
Cell[3061, 97, 168, 4, 50, "Text"],
Cell[3232, 103, 29, 0, 27, "Input"],
Cell[3264, 105, 416, 7, 104, "Text"],
Cell[3683, 114, 49, 0, 27, "Input"],
Cell[3735, 116, 163, 4, 50, "Text"],
Cell[3901, 122, 49, 0, 27, "Input"],
Cell[3953, 124, 115, 3, 32, "Text"],
Cell[4071, 129, 30, 0, 27, "Input"],
Cell[4104, 131, 45, 0, 32, "Text"],
Cell[4152, 133, 30, 0, 27, "Input"],
Cell[4185, 135, 218, 6, 50, "Text"],
Cell[4406, 143, 68, 0, 27, "Input"],
Cell[4477, 145, 141, 3, 50, "Text"],
Cell[4621, 150, 118, 3, 42, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

